@@ -5,10 +5,11 @@ from traceback import extract_tb
 from inspect import stack
 from json import dumps
 from json.decoder import JSONDecodeError
+from typing import Union
 
 
 def __getattr__(identifier: str) -> object:
-    if stack()[1].filename.split('\\')[-1] not in ('qg_bot.py', 'qg_bot_ws.py', 'qg_bot_ws_async.py', 'model.py'):
+    if stack()[1].filename.split('\\')[-1] not in ('qg_bot.py', 'qg_bot_ws.py', 'qg_bot_ws_async.py', 'model.py', 'api.py', 'async_api.py'):
         raise AssertionError("为SDK内部使用类，无法使用")
 
     return globals()[identifier.__path__]
@@ -39,37 +40,37 @@ def objectize(data: dict, flag: bool = True):
         return None
 
 
-def convert_color(color: tuple or str):
+def convert_color(color: Union[tuple, str]):
     colors = []
     if isinstance(color, tuple):
         if len(color) == 3:
             for items in color:
-                if not isinstance(items, int) or items > 255 or items < 0:
+                if not isinstance(items, int) or items not in range(256):
                     raise TypeError('RGB颜色应为一个三位数的tuple，且当中每个数值都应该介乎于0和255之间，如(255,255,255)')
-                colors.append(int(items))
+                colors.append(items)
         else:
             raise TypeError('RGB颜色应为一个三位数的tuple，且当中每个数值都应该介乎于0和255之间，如(255,255,255)')
     elif isinstance(color, str):
         colour = color.replace('#', '')
         if len(colour) == 6:
-            for items in [colour[:2], colour[2:4], colour[4:]]:
+            for items in (colour[:2], colour[2:4], colour[4:]):
                 try:
-                    local_colour = int(items, 16)
+                    items = int(items, 16)
                 except ValueError:
                     raise TypeError('该HEX颜色不存在，请检查其颜色值是否准确')
-                if local_colour > 255 or local_colour < 0:
+                if items not in range(256):
                     raise TypeError('该HEX颜色不存在，请检查其颜色值是否准确')
-                colors.append(local_colour)
+                colors.append(items)
         else:
             raise TypeError('HEX颜色应为一个 #加六位数字或字母 的string，如"#ffffff"')
     else:
-        raise TypeError('颜色值应为RGB的三位tuple，如(255,255,255)；或HEX的sting颜色，如"#ffffff"')
-    return colors[0] + 256 * colors[1] + 256 * 256 * colors[2]
+        raise TypeError('颜色值应为RGB的三位数tuple，如(255,255,255)；或HEX的sting颜色，如"#ffffff"')
+    return colors[0] + 256 * colors[1] + (256**2) * colors[2]
 
 
 def treat_msg(raw_msg: str):
     if not raw_msg:
-        return None
+        return ''
     if raw_msg[0] == '/':
         raw_msg = raw_msg[1:]
     return raw_msg.strip().replace('&amp;', '&').replace('&lt;', '<').replace('&gt;', '>').replace('\xa0', ' ')
@@ -87,6 +88,18 @@ def http_temp(return_, code: int):
             return objectize({'data': None, 'trace_id': trace_id, 'result': False})
 
 
+async def async_http_temp(return_, code: int):
+    trace_id = return_.headers['X-Tps-Trace-Id']
+    if return_.status == code:
+        return objectize({'data': None, 'trace_id': trace_id, 'result': True})
+    else:
+        try:
+            return_dict = await return_.json()
+            return objectize({'data': return_dict, 'trace_id': trace_id, 'result': False})
+        except JSONDecodeError:
+            return objectize({'data': None, 'trace_id': trace_id, 'result': False})
+
+
 def regular_temp(return_):
     trace_id = return_.headers['X-Tps-Trace-Id']
     try:
@@ -100,6 +113,19 @@ def regular_temp(return_):
         return objectize({'data': None, 'trace_id': trace_id, 'result': False})
 
 
+async def async_regular_temp(return_):
+    trace_id = return_.headers['X-Tps-Trace-Id']
+    try:
+        return_dict = await return_.json()
+        if isinstance(return_dict, dict) and 'code' in return_dict.keys():
+            result = False
+        else:
+            result = True
+        return objectize({'data': return_dict, 'trace_id': trace_id, 'result': result})
+    except JSONDecodeError:
+        return objectize({'data': None, 'trace_id': trace_id, 'result': False})
+
+
 def empty_temp(return_):
     trace_id = return_.headers['X-Tps-Trace-Id']
     try:
@@ -114,6 +140,20 @@ def empty_temp(return_):
         return objectize({'data': None, 'trace_id': trace_id, 'result': False})
 
 
+async def async_empty_temp(return_):
+    trace_id = return_.headers['X-Tps-Trace-Id']
+    try:
+        return_dict = await return_.json()
+        if not return_dict:
+            result = True
+            return_dict = None
+        else:
+            result = False
+        return objectize({'data': return_dict, 'trace_id': trace_id, 'result': result})
+    except JSONDecodeError:
+        return objectize({'data': None, 'trace_id': trace_id, 'result': False})
+
+
 def sdk_error_temp(message):
     return objectize({'data': {'code': -1, 'message': f'这是来自SDK的错误信息：{message}'}, 'trace_id': None,
                       'result': False})
